@@ -1,4 +1,7 @@
 """Core Curate App Settings
+
+Settings with the following syntax can be overwritten at the project level:
+SETTING_NAME = getattr(settings, "SETTING_NAME", "Default Value")
 """
 import os
 
