@@ -1,12 +1,16 @@
 """Curate registry app user views
 """
 from django.urls import reverse_lazy
+from django.utils.decorators import method_decorator
+from django.views import View
 
 import core_curate_app.permissions.rights as rights
 import core_main_app.utils.decorators as decorators
 from core_curate_app.views.user.views import EnterDataView
 from core_curate_app.views.user.views import ViewDataView
-from core_explore_keyword_registry_app.settings import REGISTRY_XSD_FILENAME
+from core_curate_registry_app.settings import REGISTRY_XSD_FILENAME
+from core_curate_registry_app.settings import XPATH_TITLE
+from core_curate_registry_app.utils import jquery as jquery_utils
 from core_main_app.commons import exceptions
 from core_main_app.components.version_manager import api as version_manager_api
 from core_main_app.utils.rendering import render
@@ -15,11 +19,6 @@ from core_main_registry_app.constants import CUSTOM_RESOURCE_TYPE
 from core_parser_app.components.data_structure_element import (
     api as data_structure_element_api,
 )
-from django.utils.decorators import method_decorator
-from django.views import View
-
-from core_curate_registry_app.settings import XPATH_TITLE
-from core_curate_registry_app.utils import jquery as jquery_utils
 
 
 @decorators.permission_required(
@@ -46,9 +45,9 @@ def index(request):
     }
 
     # Get custom resources for the current template
-    custom_resources = custom_resource_api.get_all_of_current_template().order_by(
-        "sort"
-    )
+    custom_resources = custom_resource_api.get_all_of_current_template(
+        request=request
+    ).order_by("sort")
 
     return render(
         request,
@@ -96,13 +95,15 @@ class StartCurate(View):
         """
         try:
             # Get custom resources for the current template
-            custom_resource = custom_resource_api.get_by_current_template_and_slug(role)
+            custom_resource = custom_resource_api.get_by_current_template_and_slug(
+                role, request=request
+            )
         except exceptions.DoesNotExist:
             custom_resource = None
 
         context = {
             "template_id": version_manager_api.get_active_global_version_manager_by_title(
-                REGISTRY_XSD_FILENAME
+                REGISTRY_XSD_FILENAME, request=request
             ).current,
             "role": role,
             "custom_resource": custom_resource,
@@ -157,13 +158,13 @@ class EnterDataRegistryView(EnterDataView):
             try:
                 # Get custom resources for the current template
                 custom_resource = custom_resource_api.get_by_current_template_and_slug(
-                    role
+                    role, request=request
                 )
             except exceptions.DoesNotExist:
                 custom_resource = None
 
             list_data_structure_element = data_structure_element_api.get_by_xpath(
-                XPATH_TITLE
+                XPATH_TITLE, request
             )
             list_data_structure_element = list(list_data_structure_element)
             data_id_list = []
